@@ -1,17 +1,19 @@
 from .augmentations.background_noise import AddBackgroundNoise
-from .augmentations.colored_noise import AddColoredNoise
 from .augmentations.band_pass_filter import BandPassFilter
+from .augmentations.band_stop_filter import BandStopFilter
+from .augmentations.colored_noise import AddColoredNoise
 from .augmentations.gain import Gain
 from .augmentations.high_pass_filter import HighPassFilter
 from .augmentations.impulse_response import ApplyImpulseResponse
 from .augmentations.low_pass_filter import LowPassFilter
 from .augmentations.peak_normalization import PeakNormalization
+from .augmentations.pitch_shift import PitchShift
 from .augmentations.polarity_inversion import PolarityInversion
 from .augmentations.shift import Shift
 from .augmentations.shuffle_channels import ShuffleChannels
-from .augmentations.pitch_shift import PitchShift
-from .core.composition import Compose
+from .augmentations.time_inversion import TimeInversion
+from .core.composition import Compose, SomeOf, OneOf
 from .utils.config import from_dict, from_yaml
 from .utils.convolution import convolve
 
-__version__ = "0.9.0"
+__version__ = "0.10.0"
